//
// Copyright 2016-2021 by Garmin Ltd. or its subsidiaries.
// Subject to Garmin SDK License Agreement and Wearables
// Application Developer Agreement.
//

import Toybox.Application.Storage;
import Toybox.Lang;
import Toybox.WatchUi;

var max_cache;

var ampm_label = [
    "AM/PM off",
    "PM only",
    "AM/PM"
];
var ccw;
var tz_cache;
var tz1 = [ 0, null ];
var tz2 = [ 0, null ];

//! The app settings menu
class Menu extends WatchUi.Menu2 {

    //! Constructor
    public function initialize() {
        var menu, entry;

        C.settings();

        Menu2.initialize(null);
        Menu2.setTitle("Config:" + V.version);

        menu = new MenuItem(ampm_label[C.ampm], null, 0, {}); 
        Menu2.addItem(menu);

        ccw = C.ccw;
        Menu2.addItem(new ToggleMenuItem("Hands CCW", null, 1, (ccw == -1), {})); 

        tz_cache = C.tz_cache;
        Menu2.addItem(new ToggleMenuItem("Reset TZ cache", null, 2, tz_cache, {})); 

        var cache = new TzCache();
        max_cache = cache.max;

        Menu2.addItem(new MenuItem("Timezone 1", null, 3, {})); 
        entry = cache.get(0);
        tz1[0] = 0;
        tz1[1] = new ToggleMenuItem(entry[0], null, 0 + 4, false, {});
        Menu2.addItem(tz1[1]);
        for (var i = 1; i < cache.max; ++i) {
            entry = cache.get(i);
            menu = new ToggleMenuItem(entry[0], null, i + 4, false, {});
            Menu2.addItem(menu);
            if (entry[0].equals(C.tz1_info[4]))
            {
                tz1[0] = i;
                tz1[1] = menu;
            }
        }
        tz1[1].setEnabled(true);

        Menu2.addItem(new MenuItem("Timezone 2", null, cache.max + 4, {})); 
        entry = cache.get(0);
        tz2[0] = 0;
        tz2[1] = new ToggleMenuItem(entry[0], null, cache.max + 5, false, {});
        Menu2.addItem(tz2[1]);
        for (var i = 1; i < cache.max; ++i) {
            entry = cache.get(i);
            menu = new ToggleMenuItem(entry[0], null, i + cache.max + 5, false, {});
            Menu2.addItem(menu);
            if (entry[0].equals(C.tz2_info[4]))
            {
                tz2[0] = i;
                tz2[1] = menu;
            }
        }
        tz2[1].setEnabled(true);
    }
}

//! Input handler for the app settings menu
class MenuDelegate extends WatchUi.Menu2InputDelegate {

    public function initialize() {
        Menu2InputDelegate.initialize();
    }

    public function onSelect(menuItem) {

        var n = menuItem.getId();
        var id = (n as Number).toNumber();
        C.logger("onSelect:" + id);
        var menu = menuItem as ToggleMenuItem;
        if (id == 0) {
            C.ampm += 1;
            if (C.ampm > 2) {
                C.ampm = 0; }
            menu.setLabel(ampm_label[C.ampm]);
        } else if (id == 1) {
            ccw = menu.isEnabled() ? -1 : 1;
        } else if (id == 2) {
            tz_cache = menu.isEnabled();
        } else if (id > 3 && id < (max_cache + 4)) {
            tz1 = toggle(id - 6, menuItem, tz1);
        } else if (id > (max_cache + 4)) {
            tz2 = toggle(id - (max_cache + 5), menuItem, tz2);
        }
    }

    public function onBack() {

        C.logger("onBack()");
        C.reconfig(C.ampm, ccw, tz_cache, tz1[0], tz2[0]);
        WatchUi.popView(WatchUi.SLIDE_IMMEDIATE);
        return;
    }

    private function toggle(id, menu, cfg)
    {

C.logger("toggle:" + id + " == " + cfg[0]);
        if (cfg[0] == id) {
            menu.setEnabled(true);
            return cfg;
        } else {
            var old = cfg[1];
            old.setEnabled(false);
            return [ id, menu ];
        }
    }

}

